@@ -62,18 +62,19 @@ class KafkaProcessor:
         Set up Kafka Producer and Consumer
         """
         conf = self.config_processor.get_kafka_config_producer()
-        key_schema, val_schema = self.config_processor.get_kafka_schemas()
-        self.key_schema = key_schema
-        self.val_schema = val_schema
+        self.key_schema = self.config_processor.get_kafka_key_schema()
+        self.val_schema = self.config_processor.get_kafka_value_schema()
 
         from fabric_mb.message_bus.producer import AvroProducerApi
-        self.producer = AvroProducerApi(conf=conf, key_schema=key_schema, record_schema=val_schema, logger=self.logger)
+        self.producer = AvroProducerApi(producer_conf=conf, key_schema_location=self.key_schema,
+                                        value_schema_location=self.val_schema, logger=self.logger)
 
         consumer_conf = self.config_processor.get_kafka_config_consumer()
         topics = [self.config_processor.get_kafka_topic()]
 
-        self.message_processor = KafkaMgmtMessageProcessor(conf=consumer_conf, key_schema=self.key_schema,
-                                                           record_schema=self.val_schema, topics=topics,
+        self.message_processor = KafkaMgmtMessageProcessor(consumer_conf=consumer_conf,
+                                                           key_schema_location=self.key_schema,
+                                                           value_schema_location=self.val_schema, topics=topics,
                                                            logger=self.logger)
 
     def initialize(self):
@@ -192,7 +193,7 @@ class KafkaProcessor:
         if refresh_token is not None:
             try:
                 proxy = CredmgrProxy(credmgr_host=self.config_processor.get_credmgr_host())
-                tokens = proxy.refresh(project_name="all", scope="all", refresh_token=refresh_token)
+                tokens = proxy.refresh(project_id=None, scope="all", refresh_token=refresh_token)
                 id_token = tokens.get('id_token', None)
             except Exception as e:
                 raise TokenException('Not a valid refresh_token! Error: {}'.format(e))
@@ -204,7 +205,7 @@ class KafkaProcessor:
 
         return id_token
 
-    def start(self, id_token: str, refresh_token: str, ignore_tokens: bool = False) -> str:
+    def start(self, id_token: str = None, refresh_token: str = None, ignore_tokens: bool = False) -> str:
         """
         Start Synchronous Kafka Processor
         @param id_token identity token
@@ -257,4 +258,4 @@ class KafkaProcessorSingleton:
             self.__instance = KafkaProcessor()
         return self.__instance
 
-    get = classmethod(get)
\ No newline at end of file
+    get = classmethod(get)
